/* Model 518 ioctl's
 */

// Model 518 physical sensor definition codes.
#define ST_RTD_385			24
#define ST_RTD_392			25
#define ST_TC_B				36
#define ST_TC_C				35
#define ST_TC_E				 1
#define ST_TC_J				27
#define ST_TC_K				28
#define ST_TC_N				34
#define ST_TC_R				31
#define ST_TC_S				30
#define ST_TC_T				29

// Bit flags in StatusFlags ------------------------------------------------

#define STAT_REJECT50HZ 0x0800 // Operating in 50 Hz rejection mode.
#define STAT_SLEEPING 0x0400 // Operating in low-power standby mode.
#define STAT_HISPEED 0x0200 // Operating in high-speed, low-resolution mode.
//					0x0100			//   spare.
#define STAT_CRMT 0x0080 // Command register empty.
#define STAT_DAV 0x0040 // Data available.
#define STAT_ALARM 0x0020 // Alarm(s) sounding.
#define STAT_FAULT 0x0010 // Board Fault LED is active.

// Bit flags used to log errors to MyFaultFlags and external err handler ---

#define FAULT_DAV 0x00000001 // DAV fault detected.
#define	FAULT_CRMT 0x00000002 // CRMT fault detected.
#define	FAULT_LED 0x00000004 // Fault LED is stuck on.
#define FAULT_OPEN 0x00000008 // Can't open I/O Driver (i.e., WinSock, WinDrvr).
#define FAULT_REG 0x00000010 // Can't register card with I/O Driver.
#define FAULT_CREATE 0x00000040	// Can't create board object instance.
#define FAULT_SEND 0x00000080 // Can't send packet to Ethernet Smart A/D.
#define FAULT_RECEIVE 0x00000080 // Ethernet Smart A/D not responding.
// Bit flags used by external error handler only ---------------------------
#define ERR_BADPARM 0x00010000 // Invalid property value (chan number too high, etc.).
#define ERR_BADCMD 0x00020000 // Command not supported on this product.




struct s518_version
{
	int ver;
	int reserved[3];
};

struct s518_cmd
{
	unsigned char val;
};

#define MAX_READ_BYTES 16
struct s518_read_mult
{
	int nbytes; 
	unsigned char val[MAX_READ_BYTES];
};

#define MAX_CMD_BYTES 16
struct s518_cmd_full {
  unsigned char cmd[MAX_CMD_BYTES];
  int len;
};

struct s518_channel_prop {
  int   idx; // channel index
  short	lsdc;		//  Logical sensor definition code.
  short	HiLim;				//  High alarm limit.
  short	LoLim;				//  Low alarm limit.
  int	LoLimEnable;		//  High alarm limit enabled.
  int	HiLimEnable;		//  Low alarm limit enabled.
  int	LoAlarm;			//  High alarm detected.
  int	HiAlarm;			//  Low alarm detected.
  int	FailHigh;			//  Fail high (versus low) on open sensor detected.
  char	Filter;				//  Filter factor.
  short	GagemVperV;			//	Gage mV/V * 10 (STDbus products only).
  short	GageMaxLoad;		//	Data value expected at max gage load (STDbus only).
};

struct s518_board_prop {
  int fault_flags;
  int board_state;
  int is_mode_high_speed;
  int is_mode_reject_50hz;
  int num_chans;
};

#define S518_IOC_TYPE 77 

#define S518_IOC_VERSION	_IOR(S518_IOC_TYPE, 0, struct s518_version)
#define S518_IOC_WRITE_BYTE	_IOWR(S518_IOC_TYPE, 1, struct s518_cmd)
#define S518_IOC_READ_BYTE	_IOWR(S518_IOC_TYPE, 2, struct s518_cmd)
#define S518_IOC_READ_MULTIPLE	_IOWR(S518_IOC_TYPE, 3, struct s518_read_mult)
#define S518_IOC_READ_STATUS	_IOWR(S518_IOC_TYPE, 4, struct s518_cmd)
#define S518_IOC_RESET_BOARD	_IO(S518_IOC_TYPE, 5)
#define S518_IOC_WRITE_COMMAND  _IOWR(S518_IOC_TYPE, 6, struct s518_cmd_full)
#define S518_IOC_GET_CHANNEL    _IOWR(S518_IOC_TYPE, 7, struct s518_channel_prop)
#define S518_IOC_GET_BOARD      _IOWR(S518_IOC_TYPE, 8, struct s518_board_prop)

// fault flags returned as integer argument
#define S518_IOC_GET_FAULTFLAGS _IOR(S518_IOC_TYPE, 9, int)
  




