#ifndef MID518_RANDOMNUMHERE_32323_H
#define MID518_RANDOMNUMHERE_32323_H

#define MAX_518_BOARDS 16
#define NUM_518_CHANNELS 8

int s518_open(int board_idx);
void s518_close(int handle);

int s518_reset_board(int handle);
int s518_calibrate(int handle, unsigned int chan, unsigned int range, double val, double *cval);
int s518_set_low_pwr_standby(int handle, unsigned int standby);
int s518_set_sensor_type(int handle, unsigned int chan, short logsdc);
int s518_get_sensor_type(int handle, unsigned int chan, short *logsdc);
int s518_set_reject_50hz(int handle);
int s518_set_hi_speed_mode(int handle);
int s518_set_fail_mode(int handle, unsigned int chan, int b_failhi);
int s518_get_fw_version(int handle, short *ver);
int s518_get_driver_version(int handle, int *ver);

// sensor data
int s518_get_ambient_temp(int handle, double *temp);
int s518_get_sensor_data(int handle, unsigned int chan, double *data);
int s518_get_all_sensors(int handle, double *data);

int s518_set_filter(int handle, unsigned int chan, char val);

// gage commands
int s518_get_gage_cal(int handle, unsigned int chan, double *slope, short *offset);
int s518_set_gage_cal(int handle, unsigned int chan, double slope, short offset);
int s518_set_gage_span(int handle, unsigned int chan, unsigned int val);
int s518_set_gage_zero(int handle, unsigned int chan);
int s518_set_gage_tare(int handle, unsigned int chan);

// diagnostics
int s518_get_eeprom_data(int handle, double *data); //data must be sizeof 7 doubles
double s518_diag_func0(int handle, unsigned int lsdc, unsigned int rawdat);
int s518_diag_func1(int handle, short *pdata);
int s518_diag_func2(int handle, unsigned int chan, short *pdata);
int s518_diag_func3(int handle, char *byte);
int s518_diag_func4(int handle, char val);
double s518_diagnostic(int handle, unsigned int ch, unsigned int id,
                       unsigned int prm, unsigned int rsiz, char *buf);
int s518_set_coefficients(int handle, unsigned int chan, double c1, double c2, double c3);

//  logsdc values for s518_set_sensor_type
// Standardized Logical Sensor Definition Codes (** indicates legacy sensor type)
typedef enum LOGSDC {                //Voltage Input Ranges:
    TYP_OLD_VOLTS_10V       =  0,    //  10V **
    TYP_OLD_VOLTS_5V        =  2,    //  5V **
    TYP_OLD_VOLTS_165V      =  4,    //  1.65V **
    TYP_OLD_VOLTS_80MV      =  7,    //  80mV **
    TYP_VOLTS_10VX          =  1,    //  10V
    TYP_VOLTS_5V            =  3,    //  5V
    TYP_VOLTS_500MV         =  5,    //  500mV
    TYP_VOLTS_100MV         =  6,    //  100mV
                                     //Thermocouples:
    TYP_OLD_TC_J            =  9,    //  J **
    TYP_OLD_TC_K            = 11,    //  K **
    TYP_OLD_TC_R            = 17,    //  R **
    TYP_OLD_TC_S            = 15,    //  S **
    TYP_OLD_TC_T            = 13,    //  T **
    TYP_TC_B                = 34,    //  B
    TYP_TC_C                = 33,    //  C
    TYP_TC_E                =  8,    //  E
    TYP_TC_J                = 10,    //  J
    TYP_TC_K                = 12,    //  K
    TYP_TC_N                = 32,    //  N
    TYP_TC_R                = 18,    //  R
    TYP_TC_S                = 16,    //  S
    TYP_TC_T                = 14,    //  T 
                                     //RTDs:
    TYP_OLD_RTD_385         = 19,    //  385 **
    TYP_OLD_RTD_392         = 21,    //  392 **
    TYP_RTD_10              = 41,    //  10 ohm
    TYP_RTD_120             = 35,    //  120 nickel
    TYP_RTD_200             = 36,    //  200 nickel
    TYP_RTD_385             = 20,    //  385 platinum
    TYP_RTD_392             = 22,    //  392 platinum
    TYP_RTD_1000            = 37,    //  1K nickel
    
    TYP_RTD_385_HIRES       = 38,    //  385 platinum, HiRes (0.0125C)
    TYP_RTD_392_HIRES       = 39,    //  392 platinum, HiRes (0.0125C)
                                     //Thermistor:
    TYP_OLD_THERMISTOR_10K  = 23,    //  10K **
    TYP_THERMISTOR_10K      = 24,    //  10K
    TYP_THERMISTOR_10KFIX   = 40,    //  10K on fixed 600K ohm range
                                     //Current Loop:
    TYP_CURLOOP             = 25,    //  4-20 mA
                                     //Gage:
    TYP_GAGE                = 26,    //  Strain/pressure gage
                                     //Resistance:
    TYP_OHMS_400            = 27,    //  400 ohm range
    TYP_OHMS_4K             = 28,    //  4K ohm range
    TYP_OHMS_600K           = 29,    //  600K ohm range
    TYP_OHMS_CUSTOM         = 30,    //  Custom resistive sensor
                                     //Disabled:
    TYP_DISABLED            = 31,    //  Remove from scan list
    
    TYP_RTD_1000_NI_2       = 42,    //1K nickel RTD (4Kohm range)-AllRegulator
    TYP_RTD_1000_PT         = 43     //1K platinum RTD (4Kohm range)-AllRegulator
} LOGSDC;



#endif
